==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkXdmf3Writer.java <==
// java wrapper for vtkXdmf3Writer object
//

package vtk;
import vtk.*;

public class vtkXdmf3Writer extends vtkDataObjectAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_2(id0); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetFileName_4();
  public String GetFileName()
    { return GetFileName_4(); }

  private native int Write_5();
  public int Write()
    { return Write_5(); }

  private native void SetLightDataLimit_6(int id0);
  public void SetLightDataLimit(int id0)
    { SetLightDataLimit_6(id0); }

  private native int GetLightDataLimit_7();
  public int GetLightDataLimit()
    { return GetLightDataLimit_7(); }

  private native void SetWriteAllTimeSteps_8(boolean id0);
  public void SetWriteAllTimeSteps(boolean id0)
    { SetWriteAllTimeSteps_8(id0); }

  private native boolean GetWriteAllTimeSteps_9();
  public boolean GetWriteAllTimeSteps()
    { return GetWriteAllTimeSteps_9(); }

  private native void WriteAllTimeStepsOn_10();
  public void WriteAllTimeStepsOn()
    { WriteAllTimeStepsOn_10(); }

  private native void WriteAllTimeStepsOff_11();
  public void WriteAllTimeStepsOff()
    { WriteAllTimeStepsOff_11(); }

  public vtkXdmf3Writer() { super(); }

  public vtkXdmf3Writer(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-2-armv6h.pkg.tar.xz: vtk/vtkXdmf3Writer.java <==
// java wrapper for vtkXdmf3Writer object
//

package vtk;
import vtk.*;

public class vtkXdmf3Writer extends vtkDataObjectAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetInputData_2(vtkDataObject id0);
  public void SetInputData(vtkDataObject id0)
    { SetInputData_2(id0); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native String GetFileName_4();
  public String GetFileName()
    { return GetFileName_4(); }

  private native int Write_5();
  public int Write()
    { return Write_5(); }

  private native void SetLightDataLimit_6(int id0);
  public void SetLightDataLimit(int id0)
    { SetLightDataLimit_6(id0); }

  private native int GetLightDataLimit_7();
  public int GetLightDataLimit()
    { return GetLightDataLimit_7(); }

  private native void SetWriteAllTimeSteps_8(boolean id0);
  public void SetWriteAllTimeSteps(boolean id0)
    { SetWriteAllTimeSteps_8(id0); }

  private native boolean GetWriteAllTimeSteps_9();
  public boolean GetWriteAllTimeSteps()
    { return GetWriteAllTimeSteps_9(); }

  private native void WriteAllTimeStepsOn_10();
  public void WriteAllTimeStepsOn()
    { WriteAllTimeStepsOn_10(); }

  private native void WriteAllTimeStepsOff_11();
  public void WriteAllTimeStepsOff()
    { WriteAllTimeStepsOff_11(); }

  public vtkXdmf3Writer() { super(); }

  public vtkXdmf3Writer(long id) { super(id); }
  public native long   VTKInit();

}
